@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*
 
 ### BEGIN LICENSE
@@ -28,11 +28,13 @@
 
 import dbus
 import os
-
+import shutil
 import locale
 
-from PyQt4.QtCore import *
-from PyQt4 import QtDBus
+import logging
+
+from PyQt5.QtCore import *
+from PyQt5 import QtDBus
 
 from models.enums import (UBUNTUKYLIN_SERVICE_PATH,
                           UBUNTUKYLIN_INTERFACE_PATH,
@@ -46,13 +48,20 @@ import multiprocessing
 
 from dbus.mainloop.glib import DBusGMainLoop
 mainloop = DBusGMainLoop(set_as_default=True)
-
+from models.globals import Globals
 #from dbus.mainloop.qt import DBusQtMainLoop
 #mainloop = DBusQtMainLoop()
 
+import gettext
+gettext.textdomain("ubuntu-kylin-software-center")
+_ = gettext.gettext
+
+LOG = logging.getLogger("uksc")
 
 
-class InstallBackend(QObject):
+class InstallBackend(QObject,Signals):
+
+    dbus_apt_process = pyqtSignal(str,str,str,int,str)
 
     def __init__(self):
         QObject.__init__(self)
@@ -60,12 +69,16 @@ class InstallBackend(QObject):
 
         self.iface = None
 
+
     def init_dbus_ifaces(self):
         try:
             bus = dbus.SystemBus(mainloop)
-        except:
-            print "could not initiate dbus"
-            self.emit(Signals.init_models_ready,"fail","初始化失败!")
+        except Exception as e:
+            if (Globals.DEBUG_DEBUG_SWITCH):
+                print("could not initiate dbus")
+            LOG.error("dbus exception:%s" % str(e))
+            #self.init_models_ready.emit("fail","初始化失败!")
+            self.init_models_ready.emit("fail", _("Initialization failed"))
             return False
 
         try:
@@ -80,11 +93,14 @@ class InstallBackend(QObject):
             self.iface.connect_to_signal("software_fetch_signal",self._on_software_fetch_signal)
             self.iface.connect_to_signal("software_apt_signal",self._on_software_apt_signal)
             self.iface.connect_to_signal("software_auth_signal",self._on_software_auth_signal)
-        except dbus.DBusException:
+        except dbus.DBusException as e:
 #            bus_name = dbus.service.BusName('com.ubuntukylin.softwarecenter', bus)
 #            self.dbusControler = SoftwarecenterDbusController(self, bus_name)
-            self.emit(Signals.init_models_ready,"fail","初始化失败!")
-            print "dbus.DBusException error"
+#           self.init_models_ready.emit("fail","初始化失败!")
+            self.init_models_ready.emit("fail",_("Initialization failed"))
+            LOG.error("dbus exception:%s" % str(e))
+            if(Globals.DEBUG_SWITCH):
+                print("dbus.DBusException error: ",str(e))
             return False
 
         return True
@@ -102,7 +118,9 @@ class InstallBackend(QObject):
         try:
             res = func(kwargs)
         except dbus.DBusException as e:
-            print "DBusException from uksc dbus",e
+            if (Globals.DEBUG_SWITCH):
+                print("DBusException from uksc dbus",e)
+            LOG.error("apt-daemon dbus exception:%s" % str(e))
             return None
 
         return res
@@ -123,9 +141,11 @@ class InstallBackend(QObject):
 # #            sendMsg = "操作取消"
 #             percent = -1
         if type == "down_fetch":
-            print "正在下载：",kwarg["uri"]
+            if (Globals.DEBUG_SWITCH):
+                #print("正在下载：",kwarg["uri"])
+                print(_("downloading"), kwarg["uri"])
 
-        self.emit(Signals.dbus_apt_process,appname,sendType,action,percent,sendMsg)
+        self.dbus_apt_process.emit(appname,sendType,action,percent,sendMsg)
 
     def _on_software_apt_signal(self,type, kwarg):
         sendType = "apt"
@@ -135,24 +155,88 @@ class InstallBackend(QObject):
         action = str(kwarg['action'])
         sendMsg = AptActionMsg[action] + AptProcessMsg[str(type)]
 
-        self.emit(Signals.dbus_apt_process,appname,sendType,action,percent,sendMsg)
+        self.dbus_apt_process.emit(appname,sendType,action,percent,sendMsg)
 
     def _on_software_auth_signal(self,type, kwarg):
 
         sendType = "auth"
         appname = str(kwarg['appname'])
-        sendMsg  = "操作取消"
+        #sendMsg  = "操作取消"
+        sendMsg = _("Operation canceled")
         action = str(kwarg['action'])
         if type == "auth_cancel":
             sendType = "cancel"
 
-        self.emit(Signals.dbus_apt_process,appname,sendType,action,0,sendMsg)
+        self.dbus_apt_process.emit(appname,sendType,action,0,sendMsg)
+
+    # 安卓环境启动检测dbus接口
+    def kydroid_dbus_ifaces(self):
+        try:
+            bus = dbus.SystemBus()
+        except Exception as e:
+            if (Globals.DEBUG_SWITCH):
+                print("could not initiate dbus")
+            LOG.error("dbus exception:%s" % str(e))
+            #self.init_models_ready.emit("fail","安卓dbus初始化失败!")
+            self.init_models_ready.emit("fail", _("Android dbus initialization failed"))
+            return False
+
+        try:
+            obj = bus.get_object('cn.kylinos.Kydroid2',
+                                 '/cn/kylinos/Kydroid2',
+                                 'cn.kylinos.Kydroid2')
+            self.kydroid_iface = dbus.Interface(obj, 'cn.kylinos.Kydroid2')
+
+#            self.call_dbus_iface("check_source_ubuntukylin")
+
+            # self.iface.connect_to_signal("software_fetch_signal",self._on_software_fetch_signal)
+            # self.iface.connect_to_signal("software_apt_signal",self._on_software_apt_signal)
+            # self.iface.connect_to_signal("software_auth_signal",self._on_software_auth_signal)
+        except dbus.DBusException as e:
+#            bus_name = dbus.service.BusName('com.ubuntukylin.softwarecenter', bus)
+#            self.dbusControler = SoftwarecenterDbusController(self, bus_name)
+#           self.init_models_ready.emit("fail","安卓dbus初始化失败!")
+            self.init_models_ready.emit("fail",_("Android dbus initialization failed"))
+            LOG.error("dbus exception:%s" % str(e))
+            if(Globals.DEBUG_SWITCH):
+                print("dbus.DBusException error: ",str(e))
+            return False
+
+        return True
+
+    def call_kydroid_dbus_iface(self, funcname, kwargs=None,kwargs2=None,kwargs3=None):
+        if self.kydroid_iface is None:
+            return None
+        func = getattr(self.kydroid_iface,funcname)
+        if func is None:
+            return None
+
+        res = None
+        try:
+            res = func(kwargs,kwargs2,kwargs3)
+        except dbus.DBusException as e:
+            if (Globals.DEBUG_SWITCH):
+                print("DBusException from kydroid dbus",e)
+            LOG.error("apt-daemon kydroid dbus exception:%s" % str(e))
+            return None
+        return res
+
+    def get_kydroid_evnrun(self,name,uid,prop):
+        return self.call_kydroid_dbus_iface("GetPropOfContainer",name,uid,prop)
+
 
     def install_deps(self, path):
         return self.call_dbus_iface(AppActions.INSTALLDEPS, path)
 
     def install_debfile(self, path):
-        return self.call_dbus_iface(AppActions.INSTALLDEBFILE, path)
+        debcache_dir = os.path.join(os.path.expanduser("~"), ".cache", "uksc", "debfile")
+        if(os.path.exists(debcache_dir) == False):
+            os.makedirs(debcache_dir)
+        if(os.path.exists(path)):
+            shutil.copy(path, debcache_dir)
+        debcache_path = os.path.join(debcache_dir,os.path.split(path)[1])
+
+        return self.call_dbus_iface(AppActions.INSTALLDEBFILE, debcache_path)
 
     def install_package(self,pkgname):
         return self.call_dbus_iface(AppActions.INSTALL,pkgname)
@@ -196,6 +280,9 @@ class InstallBackend(QObject):
     def check_dpkg_statu(self):
         self.call_dbus_iface("check_dpkg_statu")
 
+    def call_kydroid_policykit(self):
+        return self.call_dbus_iface("kydroid_policykit")
+
     def get_sources(self,except_ubuntu):
         list  = self.call_dbus_iface(AppActions.GET_SOURCES,except_ubuntu)
         resList = []
@@ -208,7 +295,9 @@ class InstallBackend(QObject):
 
         return resList
 
-from PyQt4.QtGui import *
+
+from PyQt5.QtWidgets import *
+from PyQt5.QtGui import *
 import sys
 
 
@@ -216,7 +305,8 @@ def main():
     app = QApplication(sys.argv)
 
     w = QWidget()
-    w.setWindowTitle("测试")
+    #w.setWindowTitle("测试")
+    w.setWindowTitle(_("test")  )
     w.setMaximumSize(320,240)
     w.setMinimumSize(320,240)
     w.resize(320,240)
@@ -225,7 +315,8 @@ def main():
     instBackend = InstallBackend()
     instBackend.init_dbus_ifaces()
     res = instBackend.call_dbus_iface(AppActions.INSTALL,"abe")
-    print "res=",res
+    if (Globals.DEBUG_SWITCH):
+        print("res=", res)
 
 #    instBackend.call_dbus_iface(AppActions.INSTALL,"gimp")
 #    instBackend.call_dbus_iface(AppActions.INSTALL,"bareftp")
@@ -239,7 +330,5 @@ def main():
 
 
 if __name__ == "__main__":
-
-
     main()
 
