@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -25,17 +25,23 @@
 
 
 import os
+import platform
 
 class Globals:
+
+    if(platform.machine() == 'mips64'):
+        MIPS64 = True
+    else:
+        MIPS64 = False
     # mainwindow size
     MAIN_WIDTH_NORMAL = 980
-    MAIN_HEIGHT_NORMAL = 608
+    MAIN_HEIGHT_NORMAL = 680
     MAIN_WIDTH = 980
-    MAIN_HEIGHT = 608
+    MAIN_HEIGHT = 680
 
     # card format
-    NORMALCARD_WIDTH = 212
-    NORMALCARD_HEIGHT = 88
+    NORMALCARD_WIDTH = 200
+    NORMALCARD_HEIGHT = 115
 
     # how many softwares show in a setp
     SOFTWARE_STEP_NUM = 24
@@ -44,16 +50,52 @@ class Globals:
     LAUNCH_MODE = 'quiet'
 
     # uksc version number
-    UKSC_VERSION = '1.3.6'
+    UKSC_VERSION = '1.3.10'
+
+    PUBLIC_NET_SOURCE = "deb http://archive.kylinos.cn/kylin/KYLIN-ALL ${OS} main restricted universe multiverse"
 
     # open with local deb file
     LOCAL_DEB_FILE = None
 
+    #LOG.debug and print Switch
+    DEBUG_SWITCH = False
+
     # user name
+    OS_USER=''
     USER = ''
     USER_DISPLAY = ''
+    PASSWORD = ''
+    EMAIL = ''
+    LAST_LOGIN = ''
+    USER_IDEN = ''
+    USER_LEVEL = ''
+    SET_REM = ''
+    AUTO_LOGIN = ''
+    SHOW_LOGIN = 0
     TOKEN = ''
 
+    ADVANCED_SEARCH = False
+
     NOWPAGE = -1
 
+    UPDATE_HOM = 0
+
     ALL_APPS = {}
+
+    APK_EVNRUN = 0
+
+    MAIN_CHECKBOX = 0
+
+    SOURCE_ITEMWIDTH=0
+
+    SOURCE_LIST=[]
+
+    list_chk=[]
+
+    Denot = 0
+    Dleft=0
+    ADS_NUM=0
+
+    REMOVE_SOFT = None
+
+    # SQLITR_DB=''
