@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -22,9 +22,9 @@
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from PyQt5.QtWidgets import *
+from PyQt5.QtGui import *
+from PyQt5.QtCore import *
 import sip
 
 from models.globals import Globals
@@ -79,15 +79,14 @@ class CardWidget(QWidget):
 
         cards = self.cardPanel.children()
         self.cardcount = 0
-
         for i in range(self.count()):
             self.add_card(cards[i])
 
         self.cardcount = self.count()
 
     def add_card(self, card):
-        x = int(self.cardcount % self.number_per_row) * (self.itemwidth + self.cardspacing)
-        y = int(self.cardcount / self.number_per_row) * (self.itemheight + self.cardspacing)
+        x = int(self.cardcount % int(self.number_per_row)) * (self.itemwidth + self.cardspacing)
+        y = int(self.cardcount / int(self.number_per_row)) * (self.itemheight + self.cardspacing)
 
         # resize the widget to adapt items
         nowHeight = y + self.itemheight
