@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -23,17 +23,22 @@
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from PyQt5.QtWidgets import *
+from PyQt5.QtGui import *
+from PyQt5.QtCore import *
 from ui.ukpointcard import Ui_PointCard
 from ui.starwidget import StarWidget
 from utils import run
 from utils import commontools
-from models.enums import (ITEM_LABEL_STYLE,UBUNTUKYLIN_RES_ICON_PATH,AppActions)
-from models.enums import Signals, setLongTextToElideFormat, PkgStates
-from models.globals import Globals
+from models.enums import Signals, setLongTextToElideFormat, PkgStates,AppActions
 
-class PointCard(QWidget):
+
+import gettext
+gettext.textdomain("ubuntu-kylin-software-center")
+_ = gettext.gettext
+
+
+class PointCard(QWidget,Signals):
 
     def __init__(self, app,messageBox, parent=None):
         QWidget.__init__(self, parent)
@@ -75,7 +80,7 @@ class PointCard(QWidget):
         self.ui.description.setPalette(palette)
 
         iconpath = commontools.get_icon_path(self.app.name)
-        self.ui.icon.setStyleSheet("QLabel{background-image:url('" + iconpath + "')}")
+        self.ui.icon.setStyleSheet("QLabel{background-image:url('" + iconpath + "');background-color:transparent;}")
 
         # self.ui.baseWidget.setStyleSheet("QWidget{border:0px;}")
         self.ui.name.setStyleSheet("QLabel{font-size:13px;font-weight:bold;color:#666666;}")
@@ -100,10 +105,14 @@ class PointCard(QWidget):
             self.ui.name.setStyleSheet("QLabel{font-size:12px;font-weight:bold;color:#666666;}")
 
         # convert size
-        installedsize = self.app.installedSize
+        # installedsize = self.app.installedSize
+        installedsize = self.app.packageSize
         installedsizek = installedsize / 1024
-        if(installedsizek < 1024):
-            self.ui.size.setText(str(installedsizek) + " KB")
+        if(installedsizek == 0):
+            #self.ui.size.setText("未知")
+            self.ui.size.setText(_("unknown"))
+        elif(installedsizek < 1024):
+            self.ui.size.setText(str('%.1f'%installedsizek) + " KB")
         else:
             self.ui.size.setText(str('%.2f'%(installedsizek/1024.0)) + " MB")
 
@@ -131,19 +140,22 @@ class PointCard(QWidget):
         if(app.is_installed):
             if(run.get_run_command(self.app.name) == ""):
                 self.app.status = PkgStates.NORUN
-                self.ui.btn.setText("已安装")
+                #self.ui.btn.setText("已安装")
+                self.ui.btn.setText(_("Aldy install"))
                 self.ui.btn.setEnabled(False)
                 self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
                 self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
             else:
                 self.app.status = PkgStates.RUN
-                self.ui.btn.setText("启动")
+                #self.ui.btn.setText("启动")
+                self.ui.btn.setText(_("Start"))
                 self.ui.btn.setEnabled(True)
                 self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-run-btn-3.png');}")
                 self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-run-border.png');}")
         else:
             self.app.status = PkgStates.INSTALL
-            self.ui.btn.setText("安装")
+            # self.ui.btn.setText("安装")
+            self.ui.btn.setText(_("Install"))
             self.ui.btn.setEnabled(True)
             self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
             self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
@@ -244,73 +256,83 @@ class PointCard(QWidget):
                 self.ui.baseWidget.move(0, 0)
 
     def slot_btn_click(self):
-        if(self.ui.btn.text() == "启动"):
+        #if(self.ui.btn.text() == "启动"):
+        if (self.ui.btn.text() == _("Start")):
             self.app.run()
         else:
             self.ui.btn.setEnabled(False)
             self.app.status = PkgStates.INSTALLING
-            self.ui.btn.setText("正在安装")
+            #self.ui.btn.setText("正在安装")
+            self.ui.btn.setText(_("Installing"))
             self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
             self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
-            self.emit(Signals.install_app, self.app)
-            self.emit(Signals.get_card_status, self.app.name, PkgStates.INSTALLING)
+            self.install_app.emit(self.app)
+            self.get_card_status.emit(self.app.name, PkgStates.INSTALLING)
 
     # kobe 1106
     def slot_change_btn_status(self, pkgname, status):
         if self.app.name == pkgname:
             if status == PkgStates.INSTALLING:
                 self.app.status = PkgStates.INSTALLING
-                self.ui.btn.setText("正在安装")
+                #self.ui.btn.setText("正在安装")
+                self.ui.btn.setText(_("Installing"))
                 self.ui.btn.setEnabled(False)
                 self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
                 self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
             elif status == PkgStates.REMOVING:
                 self.app.status = PkgStates.REMOVING
-                self.ui.btn.setText("正在卸载")
+                #self.ui.btn.setText("正在卸载")
+                self.ui.btn.setText(_("Unistalling"))
                 self.ui.btn.setEnabled(False)
                 self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
                 self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
             elif status == PkgStates.UPGRADING:
                 self.app.status = PkgStates.UPGRADING
-                self.ui.btn.setText("正在升级")
+                #self.ui.btn.setText("正在升级")
+                self.ui.btn.setText(_("upgrading"))
                 self.ui.btn.setEnabled(False)
                 self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-up-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-up-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-up-btn-3.png');}")
                 self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-up-border.png');}")
 
     def slot_emit_detail(self):
-        self.emit(Signals.show_app_detail, self.app)
+        self.show_app_detail.emit(self.app)
 
     def slot_work_finished(self, pkgname, action):
         if self.app.name == pkgname:
             if action in (AppActions.INSTALL,AppActions.INSTALLDEBFILE):
                 if(run.get_run_command(self.app.name) == ""):
                     self.app.status = PkgStates.NORUN
-                    self.ui.btn.setText("已安装")
+                    #self.ui.btn.setText("已安装")
+                    self.ui.btn.setText(_("Aldy install"))
                     self.ui.btn.setEnabled(False)
                     self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
                     self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
                 else:
                     self.app.status = PkgStates.RUN
-                    self.ui.btn.setText("启动")
+                    #self.ui.btn.setText("启动")
+                    self.ui.btn.setText(_("Start"))
                     self.ui.btn.setEnabled(True)
                     self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-run-btn-3.png');}")
                     self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-run-border.png');}")
             elif action == AppActions.REMOVE:
                 self.app.status = PkgStates.INSTALL
-                self.ui.btn.setText("安装")
+                #self.ui.btn.setText("安装")
+                self.ui.btn.setText(_("Install"))
                 self.ui.btn.setEnabled(True)
                 self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
                 self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
             elif action == AppActions.UPGRADE:
                 if(run.get_run_command(self.app.name) == ""):
                     self.app.status = PkgStates.NORUN
-                    self.ui.btn.setText("已安装")
+                    #self.ui.btn.setText("已安装")
+                    self.ui.btn.setText(_("Aldy install"))
                     self.ui.btn.setEnabled(False)
                     self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
                     self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
                 else:
                     self.app.status = PkgStates.RUN
-                    self.ui.btn.setText("启动")
+                    #self.ui.btn.setText("启动")
+                    self.ui.btn.setText(_("Start"))
                     self.ui.btn.setEnabled(True)
                     self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-run-btn-3.png');}")
                     self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-run-border.png');}")
@@ -319,34 +341,40 @@ class PointCard(QWidget):
         if self.app.name == pkgname:
             if action == AppActions.INSTALL:
                 self.app.status = PkgStates.INSTALL
-                self.ui.btn.setText("安装")
+                #self.ui.btn.setText("安装")
+                self.ui.btn.setText(_("Install"))
                 self.ui.btn.setEnabled(True)
             elif action == AppActions.REMOVE:
                 if(run.get_run_command(self.app.name) == ""):
                     self.app.status = PkgStates.NORUN
-                    self.ui.btn.setText("已安装")
+                    #self.ui.btn.setText("已安装")
+                    self.ui.btn.setText(_("Aldy install"))
                     self.ui.btn.setEnabled(False)
                 else:
                     self.app.status = PkgStates.RUN
-                    self.ui.btn.setText("启动")
+                    #self.ui.btn.setText("启动")
+                    self.ui.btn.setText(_("Start"))
                     self.ui.btn.setEnabled(True)
             elif action == AppActions.INSTALLDEBFILE:
                 if self.app.is_installed:
                     if run.get_run_command(self.app.name) == "":
                         self.app.status = PkgStates.NORUN
-                        self.ui.btn.setText("已安装")
+                        #self.ui.btn.setText("已安装")
+                        self.ui.btn.setText(_("Aldy install"))
                         self.ui.btn.setEnabled(False)
                         self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
                         self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
                     else:
                         self.app.status = PkgStates.RUN
-                        self.ui.btn.setText("启动")
+                        #self.ui.btn.setText("启动")
+                        self.ui.btn.setText(_("Start"))
                         self.ui.btn.setEnabled(True)
                         self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-run-btn-3.png');}")
                         self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-run-border.png');}")
                 else:
                     self.app.status = PkgStates.INSTALL
-                    self.ui.btn.setText("安装")
+                    #self.ui.btn.setText("安装")
+                    self.ui.btn.setText(_("Install"))
                     self.ui.btn.setEnabled(True)
                     self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
                     self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
